@@ -1,5 +1,3 @@
-from collective.z3cform.datagridfield.datagridfield import DataGridFieldFactory
-from collective.z3cform.datagridfield.row import DictRow
 from ftw.referencewidget.selectable import DefaultSelectable
 from ftw.referencewidget.sources import ReferenceObjSourceBinder
 from ftw.referencewidget.widget import ReferenceWidgetFactory
@@ -7,14 +5,14 @@ from plone.autoform import directives
 from plone.autoform.interfaces import IFormFieldProvider
 from plone.supermodel import model
 from plone.supermodel.model import fieldset
-from Products.CMFPlone import PloneMessageFactory as _
+from plone.base import PloneMessageFactory as pmf
+from ftw.referencewidget import _
 from z3c.relationfield.schema import RelationChoice, RelationList
-from zope import schema
-from zope.interface import alsoProvides
-from zope.interface import Interface
+from zope.interface import provider
 
 
-class IRelatedItems(Interface):
+@provider(IFormFieldProvider)
+class IRelatedItems(model.Schema):
     """Behavior, which provides the same functionality as the
     plone.app.relationfield IRelatedItems behavior, BUT it uses a different
     widget.
@@ -22,65 +20,32 @@ class IRelatedItems(Interface):
     """
 
     fieldset('categorization',
-             label=_(u'Categorization'),
+             label=pmf('Categorization'),
              fields=['relatedItems'])
 
     directives.widget(relatedItems=ReferenceWidgetFactory)
     relatedItems = RelationList(
-        title=_(u'label_related_items', default=u'Related Items'),
+        title=_('label_related_items', default='Related Items'),
         default=[],
         value_type=RelationChoice(title=u"Related",
                                   source=ReferenceObjSourceBinder()),
         required=False,
     )
 
-alsoProvides(IRelatedItems, IFormFieldProvider)
 
-
-class IRelationChoiceExample(Interface):
+@provider(IFormFieldProvider)
+class IRelationChoiceExample(model.Schema):
     """Demo behavior containing a RelationChoice (single value).
 
     """
     directives.widget(realtionchoice=ReferenceWidgetFactory)
     realtionchoice = RelationChoice(
-        title=_(u'Related Choice'),
+        title=_('Related Choice'),
         source=ReferenceObjSourceBinder(),
         default=None,
         required=False,
     )
 
-alsoProvides(IRelationChoiceExample, IFormFieldProvider)
-
-
-class IDataGridRow(model.Schema):
-    label = schema.TextLine(
-        title=u'Label',
-        default=u'I am the default label',
-    )
-
-    directives.widget(link=ReferenceWidgetFactory)
-    link = RelationChoice(
-        title=u'Link',
-        source=ReferenceObjSourceBinder(),
-        required=False,
-    )
-
-
-class IDataGridFieldExample(Interface):
-    """Demo behavior containing a DataGridField.
-
-    """
-    directives.widget('the_data_grid', DataGridFieldFactory, allow_reorder=True)
-    the_data_grid = schema.List(
-        title=u'The Data Grid',
-        value_type=DictRow(title=u'the_data_grid_row', schema=IDataGridRow),
-        required=False,
-        missing_value=[],
-    )
-
-
-alsoProvides(IDataGridFieldExample, IFormFieldProvider)
-
 
 class CustomSelectableClass(DefaultSelectable):
 
@@ -88,14 +53,15 @@ class CustomSelectableClass(DefaultSelectable):
         return self.content.Title() == 'Immutable title'
 
 
-class IRelationChoiceRestricted(Interface):
+@provider(IFormFieldProvider)
+class IRelationChoiceRestricted(model.Schema):
     """Demo behavior containing a RelationChoice (single value).
     But it's not allowd to reference a folder.
 
     """
     directives.widget(realtionchoice_restricted=ReferenceWidgetFactory)
     realtionchoice_restricted = RelationChoice(
-        title=_(u'Related Choice Restricted'),
+        title=_('Related Choice Restricted'),
         source=ReferenceObjSourceBinder(
             nonselectable=['Folder']),
         default=None,
@@ -104,7 +70,7 @@ class IRelationChoiceRestricted(Interface):
 
     directives.widget(realtionchoice_restricted_title=ReferenceWidgetFactory)
     realtionchoice_restricted_title = RelationChoice(
-        title=_(u'Related Choice Restricted Title'),
+        title=_('Related Choice Restricted Title'),
         source=ReferenceObjSourceBinder(
             selectable_class=CustomSelectableClass),
         default=None,
@@ -113,12 +79,9 @@ class IRelationChoiceRestricted(Interface):
 
     directives.widget(realtionchoice_restricted_path=ReferenceWidgetFactory)
     realtionchoice_restricted_path = RelationChoice(
-        title=_(u'Related Choice Restricted Title'),
+        title=_('Related Choice Restricted Title'),
         source=ReferenceObjSourceBinder(
             root_path='/testfolder'),
         default=None,
         required=False,
     )
-
-
-alsoProvides(IRelationChoiceRestricted, IFormFieldProvider)
