@@ -3,16 +3,15 @@ from ftw.referencewidget.selectable import ISelectable
 from plone import api
 from Products.CMFCore.interfaces import IContentish
 from zope.component.hooks import getSite
-from zope.interface import implements
+from zope.interface import implementer
 from zope.interface.verify import verifyClass
 from zope.schema.interfaces import IContextSourceBinder
 from zope.schema.interfaces import ISource
 
 
+@implementer(ISource)
 class ReferenceObjPathSource(object):
 
-    implements(ISource)
-
     def __init__(self, context, selectable_class, selectable, nonselectable,
                  override, allow_nonsearched_types, root_path):
 
@@ -38,8 +37,8 @@ class ReferenceObjPathSource(object):
             raise TypeError('Not a ISelectable class provided')
 
 
+@implementer(IContextSourceBinder)
 class ReferenceObjSourceBinder(object):
-    implements(IContextSourceBinder)
 
     def __init__(self,
                  selectable_class=None,
@@ -54,6 +53,7 @@ class ReferenceObjSourceBinder(object):
         self.override = override or False
         self.allow_nonsearched_types = allow_nonsearched_types or False
         self.root_path = root_path
+        self.query = {}  # plone.supermodel compatibility
 
     def __call__(self, context):
 
@@ -76,7 +76,7 @@ class ReferenceObjSourceBinder(object):
     def _get_root_path(self):
         if callable(self.root_path):
             return self.root_path(self.context)
-        elif isinstance(self.root_path, basestring):
+        elif isinstance(self.root_path, str):
             portal_path = '/'.join(api.portal.get().getPhysicalPath())
             return portal_path + self.root_path
         else:
